# quadrille

Square grid simulations

- Conway's Game of Life

## Credits

- Thanks to `bethlenke` at [HSBP](https://hsbp.org) for describing
  his C algorithm for grid advancement in a Conway implementation
  which was the starting point of my own approach

## License

[Mozilla Public License 2.0](https://www.mozilla.org/en-US/MPL/2.0/)

```
This Source Code Form is subject to the terms of the Mozilla Public
License, v. 2.0. If a copy of the MPL was not distributed with this
file, You can obtain one at http://mozilla.org/MPL/2.0/.
```
